@@ -172,8 +172,8 @@ if __name__ == '__main__':
         # The data was not on the server / the connection to the server did
         # not work. So try it again with the model data
         preprocessing_desc, _, _ = _get_system(args.model)
-        raw_data_source = os.path.join(utils.get_project_root(),
-                                       preprocessing_desc['data-source'])
+        raw_datapath = os.path.join(utils.get_project_root(),
+                                    preprocessing_desc['data-source'])
 
         print("hwrt version: %s" % hwrt.__version__)
         display_data(data['data'], data['id'], args.model)
