@@ -117,7 +117,8 @@ def get_database_config_file():
             return cfg['dbconfig']
         else:
             logging.info("File '%s' was not found. Adjust 'dbconfig' in your "
-                         "~/.hwrtrc file.")
+                         "~/.hwrtrc file.",
+                         cfg['dbconfig'])
     else:
         logging.info("No database connection file found. "
                      "Specify 'dbconfig' in your ~/.hwrtrc file.")
